"""Top-level package for barbell2light."""

__author__ = """Ralph Brecheisen"""
__email__ = 'ralph.brecheisen@gmail.com'
__version__ = '0.19.0'

from .castorclient import CastorClient
from .castorexportclient import CastorExportClient
from .utils import Logger
from .utils import current_time_millis
from .utils import current_time_secs
from .utils import elapsed_millis
from .utils import elapsed_secs
from .utils import duration



import os
import numpy as np

from pydicom._dicom_dict import DicomDictionary


def is_dicom_file(file_path_or_obj):
    file_obj = file_path_or_obj
    if isinstance(file_obj, str):
        if not os.path.isfile(file_obj):
            return False
        if file_obj.startswith('._'):
            return False
        file_obj = open(file_obj, "rb")
    try:
        result = file_obj.read(132).decode('ASCII')[-4:] == 'DICM'
        file_obj.seek(0)
        return result
    except UnicodeDecodeError:
        return False


def is_tag_file(file_path):
    return file_path.endswith('.tag') and not file_path.startswith('._')


def tag_for_name(name):
    for key, value in DicomDictionary.items():
        if name == value[4]:
            return hex(int(key))
    return None


def get_dictionary_items():
    return DicomDictionary.items()


def get_pixels(p, normalize=False):
    pixels = p.pixel_array
    if not normalize:
        return pixels
    if normalize is True:
        return p.RescaleSlope * pixels + p.RescaleIntercept
    if isinstance(normalize, int):
        return (pixels + np.min(pixels)) / (np.max(pixels) - np.min(pixels)) * normalize
    if isinstance(normalize, list):
        return (pixels + np.min(pixels)) / (np.max(pixels) - np.min(pixels)) * normalize[1] + normalize[0]
    return pixels



def test_get_pixels():
    import pydicom
    import numpy as np
    from barbell2light.dicom import get_pixels
    p = pydicom.read_file('/Users/Ralph/Desktop/image.dcm')
    pixels = get_pixels(p, normalize=[0, 200])
    print('[{}, {}]'.format(np.min(pixels), np.max(pixels)))
